﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

using SkiaSharp;
using SkiaSharp.Views.Forms;

namespace SkiaSharpDemo
{
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();

			var rnd = new Random();
			for (int i = 0; i < 100; i++)
			{
				var color = new Color(rnd.NextDouble(), rnd.NextDouble(), rnd.NextDouble());

				Items.Add(new ListItem { Color = color, Name = color.ToString() });
			}

			BindingContext = this;
		}

		public List<ListItem> Items { get; } = new List<ListItem>();

		private void OnPainting(object sender, SKPaintSurfaceEventArgs e)
		{
			// get the binding from the canvas
			var listItem = (sender as SKCanvasView)?.BindingContext as ListItem;
			if (listItem == null)
				return;

			var surface = e.Surface;
			var canvas = surface.Canvas;

			// clear the canvas
			canvas.Clear(listItem.Color.ToSKColor());

			// draw the name and index
			var index = Items.IndexOf(listItem);
			var text = $"{index}: {listItem.Name}";

			using (var paint = new SKPaint())
			{
				// create the paint
				paint.IsAntialias = true;
				var textSize = e.Info.Height / 2f;
				paint.TextSize = textSize;
				paint.StrokeWidth = 2;

				// draw a border
				paint.Color = SKColors.White;
				paint.IsStroke = true;
				canvas.DrawText(text, textSize / 2f, e.Info.Height - (textSize / 2f), paint);

				// then fill it
				paint.Color = SKColors.Black;
				paint.IsStroke = false;
				canvas.DrawText(text, textSize / 2f, e.Info.Height - (textSize / 2f), paint);
			}
		}

		public class ListItem
		{
			public string Name { get; set; }

			public Color Color { get; set; }
		}
	}
}
